@@ -1,6 +1,6 @@
-use crate::PortalWorkerPair;
-use ockam_core::async_trait;
+use crate::TcpPortalWorker;
 use ockam_core::compat::net::SocketAddr;
+use ockam_core::{async_trait, compat::boxed::Box};
 use ockam_core::{Address, Processor, Result, Route};
 use ockam_node::Context;
 use ockam_transport_core::TransportError;
@@ -9,13 +9,13 @@ use tracing::debug;
 
 pub(crate) struct TcpInletListenProcessor {
     inner: TcpListener,
-    onward_route: Route,
+    outlet_listener_route: Route,
 }
 
 impl TcpInletListenProcessor {
     pub(crate) async fn start(
         ctx: &Context,
-        onward_route: Route,
+        outlet_listener_route: Route,
         addr: SocketAddr,
     ) -> Result<Address> {
         let waddr = Address::random(0);
@@ -26,7 +26,7 @@ impl TcpInletListenProcessor {
             .map_err(TransportError::from)?;
         let processor = Self {
             inner,
-            onward_route,
+            outlet_listener_route,
         };
 
         ctx.start_processor(waddr.clone(), processor).await?;
@@ -41,7 +41,7 @@ impl Processor for TcpInletListenProcessor {
 
     async fn process(&mut self, ctx: &mut Self::Context) -> Result<bool> {
         let (stream, peer) = self.inner.accept().await.map_err(TransportError::from)?;
-        PortalWorkerPair::new_inlet(ctx, stream, peer, self.onward_route.clone()).await?;
+        TcpPortalWorker::new_inlet(ctx, stream, peer, self.outlet_listener_route.clone()).await?;
 
         Ok(true)
     }
